==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/AbstractContext.h <==
// abstract class gnu.java.beans.decoder.AbstractContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_AbstractContext_H_
#define _JC_gnu_java_beans_decoder_AbstractContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	_jc_gnu_java_beans_decoder_AbstractContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	_jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AbstractContext$refs	_jc_gnu_java_beans_decoder_AbstractContext$refs;
typedef struct _jc_gnu_java_beans_decoder_AbstractContext$nonrefs	_jc_gnu_java_beans_decoder_AbstractContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AbstractContext$object	_jc_gnu_java_beans_decoder_AbstractContext$object;

typedef const struct _jc_gnu_java_beans_decoder_AbstractContext$vmethods	_jc_gnu_java_beans_decoder_AbstractContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_AbstractContext$vtable	_jc_gnu_java_beans_decoder_AbstractContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_AbstractContext$vtype	_jc_gnu_java_beans_decoder_AbstractContext$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_AbstractContext$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_decoder_AbstractContext$method$getId$e3d4999a6fe37a49(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *);
extern jboolean _jc_gnu_java_beans_decoder_AbstractContext$method$isStatement$45e9c1609b256b8a(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *);
extern void _jc_gnu_java_beans_decoder_AbstractContext$method$setId$87228e8fcd6072b0(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_beans_decoder_AbstractContext$method$setStatement$a7580993a1441f73(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_AbstractContext$method_info$getId$e3d4999a6fe37a49;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractContext$method_info$isStatement$45e9c1609b256b8a;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractContext$method_info$setId$87228e8fcd6072b0;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractContext$method_info$setStatement$a7580993a1441f73;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_AbstractContext$vmethods {
	struct _jc_java_lang_String$object	*(*getId$e3d4999a6fe37a49)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *);
	jboolean	(*isStatement$45e9c1609b256b8a)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *);
	void	(*setId$87228e8fcd6072b0)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *, struct _jc_java_lang_String$object *);
	void	(*setStatement$a7580993a1441f73)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *, jboolean);
};

// Vtable
struct _jc_gnu_java_beans_decoder_AbstractContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_AbstractContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_AbstractContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AbstractContext$sub_refs {
	struct _jc_java_lang_String$object	*id;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AbstractContext$refs {
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs {
	jboolean	isStatement;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AbstractContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_AbstractContext$object {
	_jc_gnu_java_beans_decoder_AbstractContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_AbstractContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_AbstractContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_AbstractContext$vtype _jc_gnu_java_beans_decoder_AbstractContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_AbstractContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_AbstractContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_AbstractContext_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/AbstractContext.h <==
// abstract class gnu.java.beans.decoder.AbstractContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_AbstractContext_H_
#define _JC_gnu_java_beans_decoder_AbstractContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	_jc_gnu_java_beans_decoder_AbstractContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	_jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AbstractContext$refs	_jc_gnu_java_beans_decoder_AbstractContext$refs;
typedef struct _jc_gnu_java_beans_decoder_AbstractContext$nonrefs	_jc_gnu_java_beans_decoder_AbstractContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AbstractContext$object	_jc_gnu_java_beans_decoder_AbstractContext$object;

typedef const struct _jc_gnu_java_beans_decoder_AbstractContext$vmethods	_jc_gnu_java_beans_decoder_AbstractContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_AbstractContext$vtable	_jc_gnu_java_beans_decoder_AbstractContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_AbstractContext$vtype	_jc_gnu_java_beans_decoder_AbstractContext$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_AbstractContext$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_decoder_AbstractContext$method$getId$e3d4999a6fe37a49(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_beans_decoder_AbstractContext$method$isStatement$45e9c1609b256b8a(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_AbstractContext$method$setId$87228e8fcd6072b0(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_AbstractContext$method$setStatement$a7580993a1441f73(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_AbstractContext$method_info$getId$e3d4999a6fe37a49;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractContext$method_info$isStatement$45e9c1609b256b8a;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractContext$method_info$setId$87228e8fcd6072b0;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractContext$method_info$setStatement$a7580993a1441f73;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_AbstractContext$vmethods {
	struct _jc_java_lang_String$object	*(*getId$e3d4999a6fe37a49)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *) _JC_JCNI_ATTR;
	jboolean	(*isStatement$45e9c1609b256b8a)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *) _JC_JCNI_ATTR;
	void	(*setId$87228e8fcd6072b0)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setStatement$a7580993a1441f73)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractContext$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_AbstractContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_AbstractContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_AbstractContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AbstractContext$sub_refs {
	struct _jc_java_lang_String$object	*id;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AbstractContext$refs {
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs {
	jboolean	isStatement;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AbstractContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_AbstractContext$object {
	_jc_gnu_java_beans_decoder_AbstractContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_AbstractContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_AbstractContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_AbstractContext$vtype _jc_gnu_java_beans_decoder_AbstractContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_AbstractContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_AbstractContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_AbstractContext_H_ */
